// Copyright 2022 Esri
//
// Licensed under the Apache License, Version 2.0 (the "License");
// you may not use this file except in compliance with the License.
// You may obtain a copy of the License at
//
//   https://www.apache.org/licenses/LICENSE-2.0
//
// Unless required by applicable law or agreed to in writing, software
// distributed under the License is distributed on an "AS IS" BASIS,
// WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
// See the License for the specific language governing permissions and
// limitations under the License.


import SwiftUI
import ArcGIS


private class Model: ObservableObject {
    let graphicsOverlay: GraphicsOverlay = {
        let graphicsOverlay = GraphicsOverlay()

        let point = Point(x: -118.80657, y: 34.00059, spatialReference: .wgs84)
        let pointSymbol = SimpleMarkerSymbol(style: .circle, color: .orange, size: 10.0)
        pointSymbol.outline = SimpleLineSymbol(style: .solid, color: .blue, width: 2.0)

        let pointGraphic = Graphic(geometry: point, symbol: pointSymbol)

        graphicsOverlay.addGraphic(pointGraphic)

        let polyline = Polyline(
            points: [
                Point(x: -118.82152, y: 34.01395, spatialReference: .wgs84),
                Point(x: -118.81489, y: 34.00806, spatialReference: .wgs84),
                Point(x: -118.80887, y: 34.00166, spatialReference: .wgs84)
            ]
        )
        let polylineSymbol = SimpleLineSymbol(style: .solid, color: .blue, width: 3.0)

        let polylineGraphic = Graphic(geometry: polyline, symbol: polylineSymbol)

        graphicsOverlay.addGraphic(polylineGraphic)

        let polygon = Polygon(
            points: [
                Point(x: -118.81898, y: 34.01375, spatialReference: .wgs84),
                Point(x: -118.80679, y: 34.02158, spatialReference: .wgs84),
                Point(x: -118.79143, y: 34.01638, spatialReference: .wgs84),
                Point(x: -118.79596, y: 34.00856, spatialReference: .wgs84),
                Point(x: -118.80855, y: 34.00350, spatialReference: .wgs84)
            ]
        )
        let polygonSymbol = SimpleFillSymbol(style: .solid, color: .orange, outline: SimpleLineSymbol(style: .solid, color: .blue, width: 2.0))

        let polygonGraphic = Graphic(geometry: polygon, symbol: polygonSymbol)
        graphicsOverlay.addGraphic(polygonGraphic)

        return graphicsOverlay

    }()
}

struct ContentView: View {

    @State private var map: Map = {
        let map = Map(basemapStyle: .arcGISTopographic)
        map.initialViewpoint = Viewpoint(latitude: 34.02700, longitude: -118.80500, scale: 72_000)
        return map
    }()

    @StateObject private var graphicsOverlayModel = Model()

    var body: some View {

        MapView(map: map, graphicsOverlays: [graphicsOverlayModel.graphicsOverlay])

    }

}


